.. _tutorials-calculator:

======================
JSON-RPC Calculator
======================

The code for this example is located in the :mod:`examples.calculator.manage`
module.

.. automodule:: examples.calculator.manage
